@@ -8,6 +8,7 @@ lower level interfaces as they may change drastically.
 
 from pyzm.helpers.Base import Base
 import pyzm.helpers.utils as utils
+from pyzm.helpers.utils import Timer
 
 import re
 import datetime
@@ -15,6 +16,7 @@ from pyzm.helpers.Media import MediaStream
 import cv2
 import traceback
 from shapely.geometry import Polygon
+import copy
 
 class DetectSequence(Base):
     def __init__(self, logger=None, options={}):
@@ -119,14 +121,26 @@ class DetectSequence(Base):
             logger = options.get('logger')
 
         super().__init__(logger)
+        self.has_rescaled = False # only once in init
+        self.set_ml_options(options,force_reload=True)
         #self.logger.Debug(1,'WAKANDA FOREVER!!!!!!!!!!!!!!!')
+        
+    def get_ml_options(self):
+        return self.ml_options
+
+    def set_ml_options(self,options, force_reload=False):
+        """ Use this to change ml options later. Note that models will not be reloaded 
+            unless you add force_reload=True
+        """
         self.model_sequence = options.get('general', {}).get('model_sequence', 'object').split(',')    
         self.ml_options = options
         self.stream_options = None
-        self.models = {}
         self.media = None
-        self.has_rescaled = False
         self.ml_overrides = {}
+        if force_reload:
+            self.logger.Debug (1, "Resetting models, will be loaded on next run")
+            self.models = {}
+
 
     def _load_models(self, sequences):
         #print (f'***** {sequences}')
@@ -377,15 +391,12 @@ class DetectSequence(Base):
             manual_locking = True
             self.logger.Debug(3,'Using manual locking as we are only using one model')
             for seq in self.model_sequence:
-                self.ml_options[seq]['auto_lock'] = False
-        
-        
-
-        start = datetime.datetime.now()
+                self.ml_options[seq]['auto_lock'] = False        
+        t = Timer()
         media = MediaStream(stream,'video', self.stream_options, logger=self.logger )
         self.media = media
 
-        polygons = self.stream_options.get('polygons',[])
+        polygons = copy.copy(self.stream_options.get('polygons',[]))
 
         
         # Loops across all frames
@@ -397,7 +408,7 @@ class DetectSequence(Base):
             #fname = '/tmp/{}.jpg'.format(self.media.get_last_read_frame())
             #print (f'Writing to {fname}')
             #cv2.imwrite( fname ,frame)
-        
+            self.logger.Debug (1, 'perf: Starting for frame:{}'.format(self.media.get_last_read_frame()))
             _labels_in_frame = []
             _boxes_in_frame = []
             _error_boxes_in_frame = []
@@ -532,7 +543,7 @@ class DetectSequence(Base):
                 for m in self.models[seq]:
                     m.release_lock()
 
-        diff_time= (datetime.datetime.now() - start)
+        diff_time = t.stop_and_get_ms()
 
         self.logger.Debug(
             1,'perf: TOTAL detection sequence (with image loads) took: {}  to process {}'.format(diff_time, stream))
